---
title: <span class="badge object-type-scalar"></span> MicrogramPerNormalCubicMeter
---
# <span class="badge object-type-scalar"></span> MicrogramPerNormalCubicMeter

Concentration: microgram per normal cubic meter (μg/Nm³)

## Definition

```python
# Concentration: microgram per normal cubic meter (μg/Nm³)
MicrogramPerNormalCubicMeter: typing.Literal["conμgNm3"] = "conμgNm3"
```
